@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11894 2020-02-04 12:08:11Z Lavender $
+# $Id: views.py 11919 2020-02-12 07:39:14Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-02-04 21:08:11 +0900 (週二, 04 二月 2020) $
-# $Revision: 11894 $ 
+# $Date: 2020-02-12 16:39:14 +0900 (週三, 12 二月 2020) $
+# $Revision: 11919 $ 
 
 import json
 import logging
@@ -280,7 +280,7 @@ def placeOrder(self, basket, total,  # noqa (too complex (12))
                 )
         
         # bonus   
-        config = BonusSettings.objects.get()
+        config, created = BonusSettings.objects.get_or_create(id=1)
         
         if user.is_authenticated:
             b, created = Bonus.objects.get_or_create(user=user)
@@ -727,6 +727,17 @@ def updateBonus(request, *args, **kwargs):
         request, _("Update success"))
     
     return redirect(reverse("dashboard:user-detail", kwargs={'pk': pk,}))
+    
+# paypal patch
+from paypal.express import gateway
+
+originFetchResponse = gateway._fetch_response
+def newFetchResponse(method, extraParams):
+    newExtraParams = {k: v for k, v in extraParams.items() if not k.startswith("L_PAYMENTREQUEST_0_ITEMCATEGORY")}
+    
+    return originFetchResponse(method, newExtraParams)
+    
+gateway._fetch_response = newFetchResponse
 
     
 
@@ -1919,7 +1930,16 @@ class ProductTable(tables.ProductTable):
         
 catalogueViews.ProductListView.table_class = ProductTable
 
+
+# custom shop dashboard user detail template (add phone number info)
+dashboardUsersViews.UserDetailView.template_name = (
+    'shop/dashboard/users/detail.html'
+)
     
+# custom shop dashboard order detail template (add phone number info)
+dashboardOrderViews.OrderDetailView.template_name = (
+    'shop/dashboard/orders/order_detail.html'
+)
 
         
     
