@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11862 2020-01-14 12:01:35Z Lavender $
+# $Id: admin.py 11894 2020-02-04 12:08:11Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-01-14 20:01:35 +0800 (週二, 14 一月 2020) $
-# $Revision: 11862 $
+# $Date: 2020-02-04 21:08:11 +0900 (週二, 04 二月 2020) $
+# $Revision: 11894 $
 
 import os
 import datetime
@@ -34,12 +34,7 @@ from django.conf.urls import url
 from django.http import HttpResponseRedirect
 from django.contrib import messages
 
-from Iuppiter.DjangoUtil import DJANGO_VERSION
-
-if DJANGO_VERSION <= 20000: # 2.0.0:
-    from django.core.urlresolvers import reverse
-else:
-    from django.urls import reverse
+from Iuppiter.DjangoUtil import DJANGO_VERSION, reverse
 
 # 介面拖拉上傳
 
